@@ -4,7 +4,7 @@ from subprocess import check_output
 class Control:
     def _sytemd(self, command):
         args = ['systemctl', command, 'gitbucket.service']
-        check_output(args)
+        return check_output(args)
 
     def enable(self):
         self._sytemd('enable')
@@ -16,4 +16,8 @@ class Control:
         self._sytemd('start')
 
     def stop(self):
-        self._sytemd('stop')
\ No newline at end of file
+        self._sytemd('stop')
+
+    def is_active(self):
+        status_text = self._sytemd('status')
+        return 'Active: active' in status_text
\ No newline at end of file
