@@ -10,4 +10,7 @@ class GitbucketControl:
 
     def disable(self):
         self.control.disable()
-        self.control.remove_service()
\ No newline at end of file
+        self.control.remove_service()
+
+    def status(self):
+        return self.control.is_active()
\ No newline at end of file
